@@ -18,7 +18,7 @@ from typing import Tuple, List
 import numpy as np
 
 from piquasso.api.config import Config
-from piquasso.api.errors import InvalidState, InvalidParameter
+from piquasso.api.errors import InvalidState, InvalidParameter, PiquassoException
 from piquasso.api.state import State
 
 from piquasso._math.functions import gaussian_wigner_function
@@ -37,6 +37,10 @@ class GaussianState(State):
     r"""Class to represent a Gaussian state."""
 
     def __init__(self, d: int, config: Config = None) -> None:
+        """
+        Args:
+            d (int): The number of modes.
+        """
         super().__init__(config=config)
         self._d = d
         self.reset()
@@ -140,7 +144,7 @@ class GaussianState(State):
         :math:`Y = (x_1, \dots, x_d, p_1, \dots, p_d)^T`.
 
         Returns:
-            numpy.ndarray: A :math:`d`-vector.
+            numpy.ndarray: A :math:`2d`-vector where :math:`d` is the number of modes.
         """
 
         dimensionless_xxpp_mean_vector = np.concatenate(
@@ -240,10 +244,9 @@ class GaussianState(State):
         r"""Returns the xpxp-ordered mean of the state.
 
         Returns:
-            numpy.ndarray: A :math:`2d`-vector.
-                The expectation value of the quadrature operators in `xxpp`-ordering,
-                i.e. :math:`\operatorname{Tr} \rho R`, where
-                :math:`R = (x_1, p_1, \dots, x_d, p_d)^T`.
+            numpy.ndarray: A :math:`2d`-vector. The expectation value of the quadrature
+            operators in `xxpp`-ordering, i.e. :math:`\operatorname{Tr} \rho R`, where
+            :math:`R = (x_1, p_1, \dots, x_d, p_d)^T`.
         """
         T = from_xxpp_to_xpxp_transformation_matrix(self.d)
         return T @ self.xxpp_mean_vector
@@ -421,7 +424,7 @@ class GaussianState(State):
         return (self.complex_covariance + np.identity(2 * len(self))) / 2
 
     def rotated(self, phi: float) -> "GaussianState":
-        r"""Returns the copy of the current state, rotated by angle `phi`.
+        r"""Returns a copy of the current Gaussian state, rotated by an angle `phi`.
 
         Let :math:`\phi \in [ 0, 2 \pi )`. Let us define the following:
 
@@ -444,8 +447,7 @@ class GaussianState(State):
             \right),
 
         meaning that e.g. the annihilation operators :math:`a_i` are transformed just
-        multiplied by a phase factor :math:`\exp(-i \phi)` under this phase space
-        rotation, i.e.
+        by multiplying it with a phase factor :math:`\exp(-i \phi)` i.e.
 
         .. math::
             (\langle a_i \rangle_{\rho} =: )~m_i &\mapsto \exp(-i \phi) m_i \\
@@ -468,7 +470,7 @@ class GaussianState(State):
         )
 
     def reduced(self, modes: Tuple[int, ...]) -> "GaussianState":
-        """Returns the copy of the current state, reduced to the given `modes`.
+        """Returns a copy of the current state, reduced to the given `modes`.
 
         This method essentially preserves the modes specified from the representation
         of the Gaussian state, but cuts out the other modes.
@@ -567,6 +569,43 @@ class GaussianState(State):
         state = self.reduced(modes)
         return (np.trace(state._C) + state._m.conjugate() @ state._m).real
 
+    def variance_photon_number(self, modes: Tuple[int, ...]) -> float:
+        r"""
+        This method calculates the variance of the photon number operator as follows:
+
+        .. math::
+            \operatorname{\textit{Var(n)}} = \frac{1}{2} \operatorname{Tr}(
+                \sigma_{ij}/2\hbar)^2 +  \det (\sigma_{ij}/2\hbar) +
+                \frac{1}{2} \left \langle Q \right \rangle (\sigma_{ij}/2\hbar)
+                \left \langle Q \right \rangle - 0.25
+
+        where :math:`\sigma_{ij}` is the reduced :attr:`xpxp_covariance_matrix` since
+        :math:`i = j` i.e. the covariance matrix of the reduced Gaussian state and
+        :math:`\left \langle Q \right \rangle` is the :attr:`xpxp_mean_vector`.
+
+        For more details please see
+        `this article <https://arxiv.org/pdf/1612.01199.pdf>`_.
+
+        Args:
+            modes (Tuple[int, ...]): The correspoding modes at which the variance of
+                the photon number is calculated.
+
+        Returns:
+            float: Variance of the photon number operator
+        """
+        reduced_state = self.reduced(modes=modes)
+        mean, covariance = (
+            reduced_state.xpxp_mean_vector,
+            reduced_state.xpxp_covariance_matrix / (2 * self._config.hbar),
+        )
+
+        return (
+            0.5 * np.trace(covariance) ** 2
+            - np.linalg.det(covariance)
+            - 0.25
+            + (0.5 * mean @ covariance @ mean)
+        )
+
     def quadratic_polynomial_expectation(
         self, A: np.ndarray, b: np.ndarray, c: float = 0.0, phi: float = 0.0
     ) -> float:
@@ -638,8 +677,8 @@ class GaussianState(State):
         modes: Tuple[int, ...] = None,
     ) -> np.ndarray:
         r"""
-        Calculates the Wigner function values at the specified position and momentum
-        vectors, according to the equation
+        This method calculates the Wigner function values at the specified position and
+        momentum vectors, according to the following equation:
 
         .. math::
             W(r) = \frac{1}{\pi^d \sqrt{\mathrm{det} \sigma}}
@@ -682,6 +721,12 @@ class GaussianState(State):
     def get_particle_detection_probability(
         self, occupation_number: Tuple[int, ...]
     ) -> float:
+        if len(occupation_number) != self.d:
+            raise PiquassoException(
+                f"The specified occupation number should have length '{self.d}': "
+                f"occupation_number='{occupation_number}'."
+            )
+
         calculation = DensityMatrixCalculation(
             self.complex_displacement,
             self.complex_covariance,
